@@ -138,5 +138,5 @@ class Run:
         resp = interface.finish(data)
         return resp["result"] == "success"
 
-    def alert(self, alert_msg: str):
-        return interface.send_alert(self.run_id, self.team_name, self.exp_name, alert_msg)
+    def alert(self, title: str, level:str, message: str):
+        return interface.send_alert(run_id=self.run_id, team_name=self.team_name, exp_name=self.exp_name, run_name=self.run_name, title=title, msssage=message, level=level)
